# Security Policy

## Reporting a Vulnerability

If you discover a security vulnerability in this project, please report it by sending an email to shiny.brar@nrc-cnrc.gc.ca.

We will respond as quickly as possible to address the issue.

## Security Updates

We will make security updates available as soon as they are ready. Please ensure you are using the latest version of the project to benefit from these updates.

## Acknowledgments

We appreciate the efforts of the community in helping us improve the security of this project.
